=========
Changelog
=========

Version 0.2.0 (2022-12-02)
==========================

* Timestamps within the same second are rendered with the same color.
* Each Bluetooth address is rendered with its own color for easier recognition of devices.

Version 0.1.1 (2022-12-01)
==========================

Fixes a ModuleNotFoundError.

Version 0.1.0 (2022-12-01)
==========================

Initial version of HumBLE Explorer.
